diff --git a/Demos/Host/Incomplete/BluetoothHost/Lib/SDPServices.c b/Demos/Host/Incomplete/BluetoothHost/Lib/SDPServices.c
index 0af592e91fb6cbde96004cb5e178df2af0a2554d..c6dee66397bff594eda05b5f2815f4bd74bbd5b6 100644
--- a/Demos/Host/Incomplete/BluetoothHost/Lib/SDPServices.c
+++ b/Demos/Host/Incomplete/BluetoothHost/Lib/SDPServices.c
@@ -75,15 +75,15 @@ const struct
  */
 const struct
 {
-	uint8_t               Header;
-	uint8_t               Size;
+	uint8_t                  Header;
+	uint8_t                  Size;
 
-	ItemProtocol_t        L2CAP;
-	ItemProtocolChannel_t RFCOMM;
+	ItemProtocol_t           L2CAP;
+	ItemProtocol_8BitParam_t RFCOMM;
 } PROGMEM SerialPort_Attribute_ProtocolDescriptor =
 	{
 		(SDP_DATATYPE_Sequence | SDP_DATASIZE_Variable8Bit),
-		(sizeof(ItemProtocol_t) + sizeof(ItemProtocolChannel_t)),
+		(sizeof(ItemProtocol_t) + sizeof(ItemProtocol_8BitParam_t)),
 		{
 			(SDP_DATATYPE_Sequence | SDP_DATASIZE_Variable8Bit),
 			sizeof(ItemUUID_t),
diff --git a/Demos/Host/Incomplete/BluetoothHost/Lib/SDPServices.h b/Demos/Host/Incomplete/BluetoothHost/Lib/SDPServices.h
index cc3ae32ef3b0e37d0bcfaf69700fc219c3a16e58..dd8af6ec36314ca3fa42758b4ead056a9c3fdc43 100644
--- a/Demos/Host/Incomplete/BluetoothHost/Lib/SDPServices.h
+++ b/Demos/Host/Incomplete/BluetoothHost/Lib/SDPServices.h
@@ -145,8 +145,8 @@
 			} Protocol;
 		} ItemProtocol_t;
 
 		/** Structure for a list of Data Elements Sequences containing UUID Data Elements and 8-bit channel values, for service
 		 *  attributes requiring extended protocol lists.
 		 */
 		typedef struct
 		{
@@ -156,10 +156,25 @@
 			struct
 			{
 				ItemUUID_t UUID; /**< UUID to store in the protocol list Data Element sequence */
-				Item8Bit_t Channel; /**< Channel that is to be used to access the service */
+				Item8Bit_t Param; /**< 8-Bit Parameter associated with the service */
 			} Protocol;
-		} ItemProtocolChannel_t;
+		} ItemProtocol_8BitParam_t;
 		
+		/** Structure for a list of Data Elements Sequences containing UUID Data Elements and an 16-bit param value, for service
+		 *  attributes requiring extended protocol lists containing an 16-bit value.
+		 */
+		typedef struct
+		{
+			uint8_t        Header; /**< Data Element header, should be (SDP_DATATYPE_Sequence | SDP_DATASIZE_Variable8Bit) */
+			uint8_t        Size; /**< Size of the inner Data Element sequence */
+			
+			struct
+			{
+				ItemUUID_t UUID; /**< UUID to store in the protocol list Data Element sequence */
+				Item16Bit_t Channel; /**< 8-Bit Parameter associated with the service */
+			} Protocol;
+		} ItemProtocol_16BitParam_t;
+
 		/** Structure for a list of Data Elements containing language encodings, including the language ID, Encoding ID and
 		 *  Attribute base offset.
 		 */
@@ -145,8 +145,8 @@
 		} ItemProtocol_t;
 
-		/** Structure for a list of Data Elements Sequences containing UUID Data Elements and 8-bit channel values, for service
-		 *  attributes requiring extended protocol lists.
+		/** Structure for a list of Data Elements Sequences containing UUID Data Elements and an 8-bit param value, for service
+		 *  attributes requiring extended protocol lists containing an 8-bit value.
 		 */
 		typedef struct